@@ -18,7 +18,7 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include "config.h"
+#include "decrypt-utils.h"
 
 #include <stdio.h>
 #include <stdlib.h>
