@@ -15,7 +15,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-   $Id: config.c 262 2007-11-07 18:45:03Z Joerg Mayer $
+   $Id: config.c 315 2008-06-16 15:25:04Z Joerg Mayer $
 */
 
 #define _GNU_SOURCE
@@ -186,6 +186,11 @@ static const char *config_def_vendor(void)
 	return "cisco";
 }
 
+static const char *config_def_target_network(void)
+{
+	return "0.0.0.0/0.0.0.0";
+}
+
 static const struct config_names_s {
 	enum config_enum nm;
 	const int needsArgument;
@@ -356,7 +361,7 @@ static const struct config_names_s {
 		" *  1: Print minimal debug information.\n"
 		" *  2: Show statemachine and packet/payload type information.\n"
 		" *  3: Dump everything exluding authentication data.\n"
-		" * 99: Dump everything including authentication data (e.g. passwords).\n",
+		" * 99: Dump everything INCLUDING AUTHENTICATION data (e.g. PASSWORDS).\n",
 		NULL
 	}, {
 		CONFIG_ND, 0, 1,
@@ -435,6 +440,13 @@ static const struct config_names_s {
 		"<directory>",
 		"path of the trusted CA-Directory",
 		config_ca_dir
+	}, {
+		CONFIG_IPSEC_TARGET_NETWORK, 1, 1,
+		"--target-network",
+		"IPSEC target network ",
+		"<target network/netmask>",
+		"Target network in dotted decimal or CIDR notation\n",
+		config_def_target_network
 	}, {
 		0, 0, 0, NULL, NULL, NULL, NULL, NULL
 	}
