@@ -402,7 +402,15 @@ int tun_open (char *dev, enum if_mode_enum mode)
 			RegCloseKey(unit_key);
 			continue;
 		}
-		if (strcmp(comp_id, TAP_COMPONENT_ID) != 0) {
+
+		int j = 0;
+		while (TAP_COMPONENT_ID[j]) {
+			if (!strcmp(comp_id, TAP_COMPONENT_ID[j])) {
+				break;
+			}
+			j++;
+		}
+		if (!TAP_COMPONENT_ID[j]) {
 			RegCloseKey(unit_key);
 			continue;
 		}
