@@ -6,7 +6,7 @@
  * For vpnc, this list should be used as
  * reference:
  *
- * __linux__ 
+ * __linux__
  * __NetBSD__
  * __OpenBSD__
  * __FreeBSD__
@@ -43,7 +43,6 @@ int tun_get_hwaddr(int fd, char *dev, uint8_t *hwaddr);
 #define HAVE_VASPRINTF 1
 #define HAVE_ASPRINTF  1
 #define HAVE_ERROR     1
-#define HAVE_GETLINE   1
 #define HAVE_UNSETENV  1
 #define HAVE_SETENV    1
 #endif
@@ -54,7 +53,6 @@ int tun_get_hwaddr(int fd, char *dev, uint8_t *hwaddr);
 
 #define HAVE_VASPRINTF 1
 #define HAVE_ASPRINTF  1
-#define HAVE_FGETLN    1
 #define HAVE_UNSETENV  1
 #define HAVE_SETENV    1
 #endif
@@ -67,7 +65,6 @@ int tun_get_hwaddr(int fd, char *dev, uint8_t *hwaddr);
 
 #define HAVE_VASPRINTF 1
 #define HAVE_ASPRINTF  1
-#define HAVE_FGETLN    1
 #define HAVE_UNSETENV  1
 #define HAVE_SETENV    1
 #endif
@@ -83,7 +80,6 @@ int tun_get_hwaddr(int fd, char *dev, uint8_t *hwaddr);
 
 #define HAVE_VASPRINTF 1
 #define HAVE_ASPRINTF  1
-#define HAVE_FGETLN    1
 #define HAVE_UNSETENV  1
 #define HAVE_SETENV    1
 #endif
@@ -94,7 +90,6 @@ int tun_get_hwaddr(int fd, char *dev, uint8_t *hwaddr);
 
 #define HAVE_VASPRINTF 1
 #define HAVE_ASPRINTF  1
-#define HAVE_FGETLN    1
 #define HAVE_UNSETENV  1
 #define HAVE_SETENV    1
 #endif
@@ -106,9 +101,10 @@ int tun_get_hwaddr(int fd, char *dev, uint8_t *hwaddr);
 
 #define HAVE_VASPRINTF 1
 #define HAVE_ASPRINTF  1
-#define HAVE_FGETLN    1
 #define HAVE_UNSETENV  1
 #define HAVE_SETENV    1
+#if (__ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0) >= 1070
+#endif
 #endif
 
 /***************************************************************************/
@@ -119,8 +115,6 @@ int tun_get_hwaddr(int fd, char *dev, uint8_t *hwaddr);
 #define IPPROTO_ESP 50
 #endif
 
-#define getpass(prompt) getpassphrase(prompt)
-
 /* where is this defined? */
 #include <sys/socket.h>
 const char *inet_ntop(int af, const void *src, char *dst, size_t cnt);
@@ -141,12 +135,17 @@ const char *inet_ntop(int af, const void *src, char *dst, size_t cnt);
 #if defined (__CYGWIN__)
 #define HAVE_VASPRINTF 1
 #define HAVE_ASPRINTF  1
-#define HAVE_GETLINE   1
-#define HAVE_FGETLN    1
 #define HAVE_UNSETENV  1
 #define HAVE_SETENV    1
 
+#ifndef IPPROTO_ESP
 #define IPPROTO_ESP 50
+#endif
+
+#ifndef IPPROTO_ENCAP
+#define IPPROTO_ENCAP 4
+#endif
+
 #ifdef IFNAMSIZ
 #undef IFNAMSIZ
 #endif
@@ -222,9 +221,6 @@ struct ether_arp {
 #ifndef HAVE_ERROR
 extern void error(int fd, int errorno, const char *fmt, ...);
 #endif
-#ifndef HAVE_GETLINE
-extern int getline(char **line, size_t * length, FILE * stream);
-#endif
 #ifndef HAVE_VASPRINTF
 #include <stdarg.h>
 extern int vasprintf(char **strp, const char *fmt, va_list ap);
